==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QMediaContainerControl_shell.h <==
#ifndef QMEDIACONTAINERCONTROL_SHELL_H
#define QMEDIACONTAINERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediacontainercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QMediaContainerControl_shell : public QMediaContainerControl, public QtJambiShellInterface
{
public:
    QMediaContainerControl_shell(QObject* parent0 = nullptr);
    ~QMediaContainerControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString containerDescription(const QString& formatMimeType0) const override;
    QString containerFormat() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setContainerFormat(const QString& format0) override;
    QStringList supportedContainers() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaContainerControl_access : public QMediaContainerControl
{
    jstring __qt_containerDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring formatMimeType0) const;
    jstring __qt_containerFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setContainerFormat_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring format0);
    jobject __qt_supportedContainers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMEDIACONTAINERCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QMediaContainerControl_shell.h <==
#ifndef QMEDIACONTAINERCONTROL_SHELL_H
#define QMEDIACONTAINERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediacontainercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QMediaContainerControl_shell : public QMediaContainerControl, public QtJambiShellInterface
{
public:
    QMediaContainerControl_shell(QObject* parent0 = nullptr);
    ~QMediaContainerControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString containerDescription(const QString& formatMimeType0) const override;
    QString containerFormat() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setContainerFormat(const QString& format0) override;
    QStringList supportedContainers() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaContainerControl_access : public QMediaContainerControl
{
    jstring __qt_containerDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring formatMimeType0) const;
    jstring __qt_containerFormat_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setContainerFormat_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring format0);
    jobject __qt_supportedContainers_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMEDIACONTAINERCONTROL_SHELL_H
